pub fn load_oauth_token_with_mode(
mode: AuthCredentialsStoreMode,
) -> Result<Option<OpenRouterToken>, Error>Expand description
Load an OAuth token from storage with specified mode.
Returns None if no token exists or the token has expired.
pub fn load_oauth_token_with_mode(
mode: AuthCredentialsStoreMode,
) -> Result<Option<OpenRouterToken>, Error>Load an OAuth token from storage with specified mode.
Returns None if no token exists or the token has expired.