pub struct LedgerConfig {
pub enabled: bool,
pub max_entries: usize,
/* private fields */
}Fields
enabled: boolmax_entries: usizeTrait Implementations
Sourceimpl Clone for LedgerConfig
impl Clone for LedgerConfig
Sourceimpl Debug for LedgerConfig
impl Debug for LedgerConfig
Sourceimpl Default for LedgerConfig
impl Default for LedgerConfig
Sourceimpl<'de> Deserialize<'de> for LedgerConfig
impl<'de> Deserialize<'de> for LedgerConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for LedgerConfig
impl JsonSchema for LedgerConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for LedgerConfig
impl RefUnwindSafe for LedgerConfig
impl Send for LedgerConfig
impl Sync for LedgerConfig
impl Unpin for LedgerConfig
impl UnsafeUnpin for LedgerConfig
impl UnwindSafe for LedgerConfig