pub fn loop_engine_enabled(config: &AutomationConfig) -> boolExpand description
Returns true when the loop engine is enabled, respecting the
VTCODE_DISABLE_LOOP_ENGINE env-var override.
pub fn loop_engine_enabled(config: &AutomationConfig) -> boolReturns true when the loop engine is enabled, respecting the
VTCODE_DISABLE_LOOP_ENGINE env-var override.