pub struct ModelConfig {
pub model_supports_reasoning: Option<bool>,
pub model_supports_reasoning_effort: Option<bool>,
/* private fields */
}Expand description
Model-specific behavior configuration
Fields
model_supports_reasoning: Option<bool>Manually enable reasoning support for models that are not natively recognized. Note: Setting this to false will NOT disable reasoning for known reasoning models (e.g. GPT-5).
model_supports_reasoning_effort: Option<bool>Manually enable reasoning effort support for models that are not natively recognized. Note: Setting this to false will NOT disable reasoning effort for known models.