pub struct AutoModeEnvironmentConfig {
pub trusted_paths: Vec<String>,
pub trusted_domains: Vec<String>,
pub trusted_git_hosts: Vec<String>,
pub trusted_git_orgs: Vec<String>,
pub trusted_services: Vec<String>,
}Expand description
Trust-boundary configuration for auto mode.
Fields
trusted_paths: Vec<String>trusted_domains: Vec<String>trusted_git_hosts: Vec<String>trusted_git_orgs: Vec<String>trusted_services: Vec<String>Trait Implementations
Sourceimpl Clone for AutoModeEnvironmentConfig
impl Clone for AutoModeEnvironmentConfig
Sourcefn clone(&self) -> AutoModeEnvironmentConfig
fn clone(&self) -> AutoModeEnvironmentConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for AutoModeEnvironmentConfig
impl Debug for AutoModeEnvironmentConfig
Sourceimpl Default for AutoModeEnvironmentConfig
impl Default for AutoModeEnvironmentConfig
Sourcefn default() -> AutoModeEnvironmentConfig
fn default() -> AutoModeEnvironmentConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for AutoModeEnvironmentConfig
impl<'de> Deserialize<'de> for AutoModeEnvironmentConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AutoModeEnvironmentConfig
impl JsonSchema for AutoModeEnvironmentConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AutoModeEnvironmentConfig
impl RefUnwindSafe for AutoModeEnvironmentConfig
impl Send for AutoModeEnvironmentConfig
impl Sync for AutoModeEnvironmentConfig
impl Unpin for AutoModeEnvironmentConfig
impl UnsafeUnpin for AutoModeEnvironmentConfig
impl UnwindSafe for AutoModeEnvironmentConfig