pub struct AutoPermissionEnvironmentConfig {
pub trusted_paths: Vec<String>,
pub trusted_domains: Vec<String>,
pub trusted_git_hosts: Vec<String>,
pub trusted_git_orgs: Vec<String>,
pub trusted_services: Vec<String>,
}Expand description
Trust-boundary configuration for auto permission review.
Fields
trusted_paths: Vec<String>trusted_domains: Vec<String>trusted_git_hosts: Vec<String>trusted_git_orgs: Vec<String>trusted_services: Vec<String>Trait Implementations
Sourceimpl<'de> Deserialize<'de> for AutoPermissionEnvironmentConfig
impl<'de> Deserialize<'de> for AutoPermissionEnvironmentConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for AutoPermissionEnvironmentConfig
impl JsonSchema for AutoPermissionEnvironmentConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for AutoPermissionEnvironmentConfig
impl RefUnwindSafe for AutoPermissionEnvironmentConfig
impl Send for AutoPermissionEnvironmentConfig
impl Sync for AutoPermissionEnvironmentConfig
impl Unpin for AutoPermissionEnvironmentConfig
impl UnsafeUnpin for AutoPermissionEnvironmentConfig
impl UnwindSafe for AutoPermissionEnvironmentConfig