pub struct MoonshotPromptCacheSettings {
pub enabled: bool,
}Expand description
Moonshot prompt caching configuration (leverages server-side reuse)
Fields
enabled: boolTrait Implementations
Sourceimpl Clone for MoonshotPromptCacheSettings
impl Clone for MoonshotPromptCacheSettings
Sourcefn clone(&self) -> MoonshotPromptCacheSettings
fn clone(&self) -> MoonshotPromptCacheSettings
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for MoonshotPromptCacheSettings
impl Debug for MoonshotPromptCacheSettings
Sourceimpl<'de> Deserialize<'de> for MoonshotPromptCacheSettings
impl<'de> Deserialize<'de> for MoonshotPromptCacheSettings
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for MoonshotPromptCacheSettings
impl JsonSchema for MoonshotPromptCacheSettings
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for MoonshotPromptCacheSettings
impl RefUnwindSafe for MoonshotPromptCacheSettings
impl Send for MoonshotPromptCacheSettings
impl Sync for MoonshotPromptCacheSettings
impl Unpin for MoonshotPromptCacheSettings
impl UnsafeUnpin for MoonshotPromptCacheSettings
impl UnwindSafe for MoonshotPromptCacheSettings