pub struct ProviderPromptCachingConfig {
pub openai: OpenAIPromptCacheSettings,
pub anthropic: AnthropicPromptCacheSettings,
pub gemini: GeminiPromptCacheSettings,
pub openrouter: OpenRouterPromptCacheSettings,
pub deepseek: DeepSeekPromptCacheSettings,
/* private fields */
}Expand description
Per-provider configuration overrides
Fields
openai: OpenAIPromptCacheSettingsanthropic: AnthropicPromptCacheSettingsgemini: GeminiPromptCacheSettingsopenrouter: OpenRouterPromptCacheSettingsdeepseek: DeepSeekPromptCacheSettingsTrait Implementations
Sourceimpl Clone for ProviderPromptCachingConfig
impl Clone for ProviderPromptCachingConfig
Sourceimpl Debug for ProviderPromptCachingConfig
impl Debug for ProviderPromptCachingConfig
Sourceimpl<'de> Deserialize<'de> for ProviderPromptCachingConfig
impl<'de> Deserialize<'de> for ProviderPromptCachingConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for ProviderPromptCachingConfig
impl JsonSchema for ProviderPromptCachingConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for ProviderPromptCachingConfig
impl RefUnwindSafe for ProviderPromptCachingConfig
impl Send for ProviderPromptCachingConfig
impl Sync for ProviderPromptCachingConfig
impl Unpin for ProviderPromptCachingConfig
impl UnsafeUnpin for ProviderPromptCachingConfig
impl UnwindSafe for ProviderPromptCachingConfig