pub struct AnthropicMemoryConfig {
pub enabled: bool,
}Fields
enabled: boolTrait Implementations
Sourceimpl Clone for AnthropicMemoryConfig
impl Clone for AnthropicMemoryConfig
Sourceimpl Debug for AnthropicMemoryConfig
impl Debug for AnthropicMemoryConfig
Sourceimpl Default for AnthropicMemoryConfig
impl Default for AnthropicMemoryConfig
Sourceimpl<'de> Deserialize<'de> for AnthropicMemoryConfig
impl<'de> Deserialize<'de> for AnthropicMemoryConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for AnthropicMemoryConfig
Sourceimpl JsonSchema for AnthropicMemoryConfig
impl JsonSchema for AnthropicMemoryConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for AnthropicMemoryConfig
impl PartialEq for AnthropicMemoryConfig
Sourceimpl Serialize for AnthropicMemoryConfig
impl Serialize for AnthropicMemoryConfig
impl StructuralPartialEq for AnthropicMemoryConfig