pub struct IdeContextProviderConfig {
pub enabled: bool,
}Fields
enabled: boolTrait Implementations
Sourceimpl Clone for IdeContextProviderConfig
impl Clone for IdeContextProviderConfig
Sourcefn clone(&self) -> IdeContextProviderConfig
fn clone(&self) -> IdeContextProviderConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for IdeContextProviderConfig
impl Debug for IdeContextProviderConfig
Sourceimpl Default for IdeContextProviderConfig
impl Default for IdeContextProviderConfig
Sourceimpl<'de> Deserialize<'de> for IdeContextProviderConfig
impl<'de> Deserialize<'de> for IdeContextProviderConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for IdeContextProviderConfig
impl JsonSchema for IdeContextProviderConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for IdeContextProviderConfig
impl RefUnwindSafe for IdeContextProviderConfig
impl Send for IdeContextProviderConfig
impl Sync for IdeContextProviderConfig
impl Unpin for IdeContextProviderConfig
impl UnsafeUnpin for IdeContextProviderConfig
impl UnwindSafe for IdeContextProviderConfig