pub struct ConfigLayerStack { /* private fields */ }Expand description
A stack of configuration layers, ordered from lowest to highest precedence.
Implementations
Sourceimpl ConfigLayerStack
impl ConfigLayerStack
Sourcepub fn new(layers: Vec<ConfigLayerEntry>) -> Self
pub fn new(layers: Vec<ConfigLayerEntry>) -> Self
Create a new configuration layer stack.
Sourcepub fn effective_config_with_origins(
&self,
) -> (TomlValue, HashMap<String, ConfigLayerMetadata>)
pub fn effective_config_with_origins( &self, ) -> (TomlValue, HashMap<String, ConfigLayerMetadata>)
Merge all layers and return an origin map (path -> winning layer metadata).
Sourcepub fn effective_config_without_origins(&self) -> TomlValue
pub fn effective_config_without_origins(&self) -> TomlValue
Merge all enabled layers without origin tracking.
Sourcepub fn layers(&self) -> &[ConfigLayerEntry]
pub fn layers(&self) -> &[ConfigLayerEntry]
Get all layers in the stack.