Module watch

Module watch 

Structs

ConfigWatcher
Configuration watcher that monitors config files for changes and automatically reloads them when modifications are detected.
SimpleConfigWatcher
Simple config watcher that polls file mtimes instead of using filesystem events.