pub struct UiFullscreenConfig {
pub mouse_capture: bool,
pub copy_on_select: bool,
pub scroll_speed: u8,
}Fields
mouse_capture: boolCapture mouse events inside the fullscreen UI. Can also be controlled via VTCODE_FULLSCREEN_MOUSE_CAPTURE=0/1.
copy_on_select: boolCopy selected transcript text immediately when the mouse selection ends. Can also be controlled via VTCODE_FULLSCREEN_COPY_ON_SELECT=0/1.
scroll_speed: u8Multiplier applied to mouse wheel transcript scrolling in fullscreen mode. Values are clamped to the range 1..=20. Can also be controlled via VTCODE_FULLSCREEN_SCROLL_SPEED.