pub struct StatusLineConfig {
pub mode: StatusLineMode,
pub command: Option<String>,
pub refresh_interval_ms: u64,
pub command_timeout_ms: u64,
pub show_clock: bool,
}Fields
mode: StatusLineModecommand: Option<String>refresh_interval_ms: u64command_timeout_ms: u64show_clock: boolShow the current system time (HH:MM:SS) on the status line (default: true).
Implementations
Sourceimpl StatusLineConfig
impl StatusLineConfig
Sourcepub fn effective_mode(&self) -> StatusLineMode
pub fn effective_mode(&self) -> StatusLineMode
Get the effective status line mode, using defaults for unset values.
Following Codex PR #12015’s pattern for default configuration fallback, this method ensures that when a status line config is not explicitly set, sensible defaults are applied (automatic status line by default).