pub struct AuthCopilotConfig {
pub command: Option<String>,
pub host: Option<String>,
pub available_tools: Vec<String>,
pub excluded_tools: Vec<String>,
pub vtcode_tool_allowlist: Vec<String>,
pub startup_timeout_secs: u64,
pub auth_timeout_secs: u64,
}Fields
command: Option<String>host: Option<String>available_tools: Vec<String>excluded_tools: Vec<String>vtcode_tool_allowlist: Vec<String>startup_timeout_secs: u64auth_timeout_secs: u64Trait Implementations
Sourceimpl Clone for CopilotAuthConfig
impl Clone for CopilotAuthConfig
Sourcefn clone(&self) -> CopilotAuthConfig
fn clone(&self) -> CopilotAuthConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for CopilotAuthConfig
impl Debug for CopilotAuthConfig
Sourceimpl Default for CopilotAuthConfig
impl Default for CopilotAuthConfig
Sourcefn default() -> CopilotAuthConfig
fn default() -> CopilotAuthConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for CopilotAuthConfigwhere
CopilotAuthConfig: Default,
impl<'de> Deserialize<'de> for CopilotAuthConfigwhere
CopilotAuthConfig: Default,
Sourcefn deserialize<__D>(
__deserializer: __D,
) -> Result<CopilotAuthConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(
__deserializer: __D,
) -> Result<CopilotAuthConfig, <__D as Deserializer<'de>>::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for CopilotAuthConfig
impl JsonSchema for CopilotAuthConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl Serialize for CopilotAuthConfig
impl Serialize for CopilotAuthConfig
Sourcefn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
fn serialize<__S>(
&self,
__serializer: __S,
) -> Result<<__S as Serializer>::Ok, <__S as Serializer>::Error>where
__S: Serializer,
Serialize this value into the given Serde serializer. Read more