pub struct SubagentRuntimeLimits {
pub enabled: bool,
pub max_concurrent: usize,
pub max_depth: usize,
pub default_timeout_seconds: u64,
pub auto_delegate_read_only: bool,
pub background: BackgroundSubagentConfig,
}Fields
enabled: boolmax_concurrent: usizemax_depth: usizedefault_timeout_seconds: u64auto_delegate_read_only: boolbackground: BackgroundSubagentConfigTrait Implementations
Sourceimpl Clone for SubagentRuntimeLimits
impl Clone for SubagentRuntimeLimits
Sourceimpl Debug for SubagentRuntimeLimits
impl Debug for SubagentRuntimeLimits
Sourceimpl Default for SubagentRuntimeLimits
impl Default for SubagentRuntimeLimits
Sourceimpl<'de> Deserialize<'de> for SubagentRuntimeLimits
impl<'de> Deserialize<'de> for SubagentRuntimeLimits
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for SubagentRuntimeLimits
Sourceimpl JsonSchema for SubagentRuntimeLimits
impl JsonSchema for SubagentRuntimeLimits
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for SubagentRuntimeLimits
impl PartialEq for SubagentRuntimeLimits
Sourceimpl Serialize for SubagentRuntimeLimits
impl Serialize for SubagentRuntimeLimits
impl StructuralPartialEq for SubagentRuntimeLimits