pub struct SubagentSpec {Show 24 fields
pub name: String,
pub description: String,
pub prompt: String,
pub tools: Option<Vec<String>>,
pub disallowed_tools: Vec<String>,
pub model: Option<String>,
pub color: Option<String>,
pub reasoning_effort: Option<ReasoningEffortLevel>,
pub permissions: AgentPermissionsConfig,
pub skills: Vec<String>,
pub mcp_servers: Vec<SubagentMcpServer>,
pub hooks: Option<HooksConfig>,
pub background: bool,
pub mode: AgentMode,
pub max_turns: Option<usize>,
pub nickname_candidates: Vec<String>,
pub initial_prompt: Option<String>,
pub memory: Option<SubagentMemoryScope>,
pub isolation: Option<IsolationMode>,
pub aliases: Vec<String>,
pub source: SubagentSource,
pub file_path: Option<PathBuf>,
pub warnings: Vec<String>,
pub tool_policy_overrides: BTreeMap<String, ToolPolicy>,
}Fields
name: Stringdescription: Stringprompt: Stringtools: Option<Vec<String>>disallowed_tools: Vec<String>model: Option<String>color: Option<String>reasoning_effort: Option<ReasoningEffortLevel>permissions: AgentPermissionsConfigskills: Vec<String>mcp_servers: Vec<SubagentMcpServer>hooks: Option<HooksConfig>background: boolmode: AgentModemax_turns: Option<usize>nickname_candidates: Vec<String>initial_prompt: Option<String>memory: Option<SubagentMemoryScope>isolation: Option<IsolationMode>aliases: Vec<String>source: SubagentSourcefile_path: Option<PathBuf>warnings: Vec<String>tool_policy_overrides: BTreeMap<String, ToolPolicy>Per-tool policy overrides applied when this agent becomes active.
Keys are tool names, values are the policy to enforce.
Applied on top of (and overriding) the global [tools.policies] from vtcode.toml.
Implementations
Sourceimpl SubagentSpec
impl SubagentSpec
pub const fn is_primary(&self) -> bool
pub const fn is_subagent(&self) -> bool
pub fn is_read_only(&self) -> bool
pub fn matches_name(&self, candidate: &str) -> bool