pub struct TerminalTitleConfig {
pub items: Option<Vec<String>>,
}Fields
items: Option<Vec<String>>Trait Implementations
Sourceimpl Clone for TerminalTitleConfig
impl Clone for TerminalTitleConfig
Sourceimpl Debug for TerminalTitleConfig
impl Debug for TerminalTitleConfig
Sourceimpl Default for TerminalTitleConfig
impl Default for TerminalTitleConfig
Sourceimpl<'de> Deserialize<'de> for TerminalTitleConfig
impl<'de> Deserialize<'de> for TerminalTitleConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for TerminalTitleConfig
Sourceimpl JsonSchema for TerminalTitleConfig
impl JsonSchema for TerminalTitleConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for TerminalTitleConfig
impl PartialEq for TerminalTitleConfig
Sourceimpl Serialize for TerminalTitleConfig
impl Serialize for TerminalTitleConfig
impl StructuralPartialEq for TerminalTitleConfig