pub enum CapabilityLevel {
Basic,
FileReading,
FileListing,
Bash,
Editing,
CodeSearch,
}Expand description
Workshop agent capability levels
Variants
Basic
Basic chat only
FileReading
Can read files
FileListing
Can read files and list directories
Bash
Can read files, list directories, and run bash commands
Editing
Can read files, list directories, run bash commands, and edit files
CodeSearch
Full capabilities including code search