pub struct HistoryConfig {
pub persistence: HistoryPersistence,
pub max_bytes: Option<usize>,
}Expand description
Codex-compatible history persistence settings.
Fields
persistence: HistoryPersistencemax_bytes: Option<usize>Trait Implementations
Sourceimpl Clone for HistoryConfig
impl Clone for HistoryConfig
Sourcefn clone(&self) -> HistoryConfig
fn clone(&self) -> HistoryConfig
Returns a duplicate of the value. Read more
1.0.0 · Sourcefn clone_from(&mut self, source: &Self)
fn clone_from(&mut self, source: &Self)
Performs copy-assignment from
source. Read moreSourceimpl Debug for HistoryConfig
impl Debug for HistoryConfig
Sourceimpl Default for HistoryConfig
impl Default for HistoryConfig
Sourcefn default() -> HistoryConfig
fn default() -> HistoryConfig
Returns the “default value” for a type. Read more
Sourceimpl<'de> Deserialize<'de> for HistoryConfig
impl<'de> Deserialize<'de> for HistoryConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
Sourceimpl JsonSchema for HistoryConfig
impl JsonSchema for HistoryConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreAuto Trait Implementations
impl Freeze for HistoryConfig
impl RefUnwindSafe for HistoryConfig
impl Send for HistoryConfig
impl Sync for HistoryConfig
impl Unpin for HistoryConfig
impl UnsafeUnpin for HistoryConfig
impl UnwindSafe for HistoryConfig