pub struct CustomProviderCommandAuthConfig {
pub command: String,
pub args: Vec<String>,
pub cwd: Option<PathBuf>,
pub timeout_ms: u64,
pub refresh_interval_ms: u64,
}Expand description
Command-backed bearer token configuration for a custom provider.
Fields
command: StringCommand to execute. Bare names are resolved via PATH.
args: Vec<String>Optional command arguments.
cwd: Option<PathBuf>Optional working directory for the token command.
timeout_ms: u64Maximum time to wait for the command to complete successfully.
refresh_interval_ms: u64Maximum age for the cached token before rerunning the command.