pub struct OpenAIPromptCacheSettings {
pub enabled: bool,
pub min_prefix_tokens: u32,
pub idle_expiration_seconds: u64,
pub surface_metrics: bool,
pub prompt_cache_key_mode: OpenAIPromptCacheKeyMode,
pub prompt_cache_retention: Option<String>,
}Expand description
OpenAI prompt caching controls (automatic with metrics)
Fields
enabled: boolmin_prefix_tokens: u32idle_expiration_seconds: u64surface_metrics: boolprompt_cache_key_mode: OpenAIPromptCacheKeyModeStrategy for generating OpenAI prompt_cache_key.
Session mode derives one stable key per VT Code conversation.
prompt_cache_retention: Option<String>Optional prompt cache retention string to pass directly into OpenAI Responses API.
Supported values are “in_memory” and “24h”. If set, VT Code will include
prompt_cache_retention in the request body to extend the model-side prompt
caching window or request the explicit in-memory policy.
Implementations