pub struct PtyConfig {
pub enabled: bool,
pub default_rows: u16,
pub default_cols: u16,
pub max_sessions: usize,
pub command_timeout_seconds: u64,
pub stdout_tail_lines: usize,
pub scrollback_lines: usize,
pub max_scrollback_bytes: usize,
pub large_output_threshold_kb: usize,
pub preferred_shell: Option<String>,
pub shell_zsh_fork: bool,
pub zsh_path: Option<String>,
}Expand description
PTY configuration
Fields
enabled: boolEnable PTY support for interactive commands
default_rows: u16Default terminal rows for PTY sessions
default_cols: u16Default terminal columns for PTY sessions
max_sessions: usizeMaximum number of concurrent PTY sessions
command_timeout_seconds: u64Command timeout in seconds (prevents hanging commands)
stdout_tail_lines: usizeNumber of recent PTY output lines to display in the chat transcript
scrollback_lines: usizeTotal scrollback buffer size (lines) retained per PTY session
max_scrollback_bytes: usizeMaximum bytes of output to retain per PTY session (prevents memory explosion)
large_output_threshold_kb: usizeThreshold (KB) at which to auto-spool large outputs to disk instead of memory
preferred_shell: Option<String>Preferred shell program for PTY sessions (e.g. “zsh”, “bash”); falls back to $SHELL
shell_zsh_fork: boolFeature-gated shell runtime path that routes shell execution through zsh EXEC_WRAPPER hooks.
zsh_path: Option<String>Optional absolute path to patched zsh used when shell_zsh_fork is enabled.
Implementations