pub struct BackgroundSubagentConfig {
pub enabled: bool,
pub default_agent: Option<String>,
pub refresh_interval_ms: u64,
pub auto_restore: bool,
/* private fields */
}Fields
enabled: booldefault_agent: Option<String>refresh_interval_ms: u64auto_restore: boolTrait Implementations
Sourceimpl Clone for BackgroundSubagentConfig
impl Clone for BackgroundSubagentConfig
Sourceimpl Debug for BackgroundSubagentConfig
impl Debug for BackgroundSubagentConfig
Sourceimpl Default for BackgroundSubagentConfig
impl Default for BackgroundSubagentConfig
Sourceimpl<'de> Deserialize<'de> for BackgroundSubagentConfig
impl<'de> Deserialize<'de> for BackgroundSubagentConfig
Sourcefn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
fn deserialize<__D>(__deserializer: __D) -> Result<Self, __D::Error>where
__D: Deserializer<'de>,
Deserialize this value from the given Serde deserializer. Read more
impl Eq for BackgroundSubagentConfig
Sourceimpl JsonSchema for BackgroundSubagentConfig
impl JsonSchema for BackgroundSubagentConfig
Sourcefn schema_id() -> Cow<'static, str>
fn schema_id() -> Cow<'static, str>
Returns a string that uniquely identifies the schema produced by this type. Read more
Sourcefn json_schema(generator: &mut SchemaGenerator) -> Schema
fn json_schema(generator: &mut SchemaGenerator) -> Schema
Generates a JSON Schema for this type. Read more
Sourcefn inline_schema() -> bool
fn inline_schema() -> bool
Whether JSON Schemas generated for this type should be included directly in parent schemas,
rather than being re-used where possible using the
$ref keyword. Read moreSourceimpl PartialEq for BackgroundSubagentConfig
impl PartialEq for BackgroundSubagentConfig
Sourceimpl Serialize for BackgroundSubagentConfig
impl Serialize for BackgroundSubagentConfig
impl StructuralPartialEq for BackgroundSubagentConfig